==> gorilla-notes-0.3.0-20200830.150112-12.jar: public/js/compiled/cljs-runtime/module$node_modules$ag_grid_react$lib$agGridReact.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$ag_grid_react$lib$agGridReact=function(global,require,module,exports){function addProperties(listOfProps,propType){listOfProps.forEach(function(propKey){AgGridReact[propKey]=propType})}var __extends=this&&this.__extends||function(){var extendStatics=function(d$jscomp$0,b$jscomp$0){extendStatics=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(d,b){d.__proto__=b}||function(d,b){for(var p in b)b.hasOwnProperty(p)&&(d[p]=b[p])};return extendStatics(d$jscomp$0,
b$jscomp$0)};return function(d,b){function __(){this.constructor=d}extendStatics(d,b);d.prototype=null===b?Object.create(b):(__.prototype=b.prototype,new __)}}(),__spreadArrays=this&&this.__spreadArrays||function(){for(var s=0,i=0,il=arguments.length;i<il;i++)s+=arguments[i].length;s=Array(s);var k=0;for(i=0;i<il;i++)for(var a=arguments[i],j=0,jl=a.length;j<jl;j++,k++)s[k]=a[j];return s};Object.defineProperty(exports,"__esModule",{value:!0});var React=require("module$node_modules$react$index");global=
require("module$node_modules$react$index");module=require("module$node_modules$prop_types$index");var ag_grid_community_1=require("module$node_modules$ag_grid_community$dist$ag_grid_community_cjs"),agGridColumn_1=require("module$node_modules$ag_grid_react$lib$agGridColumn"),reactComponent_1=require("module$node_modules$ag_grid_react$lib$reactComponent"),changeDetectionService_1=require("module$node_modules$ag_grid_react$lib$changeDetectionService"),AgGridReact=function(_super){function AgGridReact(props,
state){var _this=_super.call(this,props,state)||this;_this.props=props;_this.state=state;_this.changeDetectionService=new changeDetectionService_1.ChangeDetectionService;_this.api=null;_this.portals=[];_this.hasPendingPortalUpdate=!1;_this.destroyed=!1;return _this}__extends(AgGridReact,_super);AgGridReact.prototype.render=function(){var _this=this;return React.createElement("div",{style:this.createStyleForDiv(),ref:function(e){_this.eGridDiv=e}},this.portals)};AgGridReact.prototype.createStyleForDiv=
function(){var style={height:"100%"},containerStyle=this.props.containerStyle;containerStyle&&Object.keys(containerStyle).forEach(function(key){style[key]=containerStyle[key]});return style};AgGridReact.prototype.componentDidMount=function(){var modules=this.props.modules||[];modules={providedBeanInstances:{agGridReact:this,frameworkComponentWrapper:new ReactFrameworkComponentWrapper(this)},modules};var gridOptions=this.props.gridOptions||{};agGridColumn_1.AgGridColumn.hasChildColumns(this.props)&&
(gridOptions.columnDefs=agGridColumn_1.AgGridColumn.mapChildColumnDefs(this.props));this.gridOptions=ag_grid_community_1.ComponentUtil.copyAttributesToGridOptions(gridOptions,this.props);new ag_grid_community_1.Grid(this.eGridDiv,this.gridOptions,modules);this.api=this.gridOptions.api;this.columnApi=this.gridOptions.columnApi};AgGridReact.prototype.waitForInstance=function(reactComponent,resolve,runningTime){var _this=this;void 0===runningTime&&(runningTime=0);this.destroyed?resolve(null):reactComponent.isStatelessComponent()&&
reactComponent.statelessComponentRendered()?resolve(null):!reactComponent.isStatelessComponent()&&reactComponent.getFrameworkComponentInstance()?resolve(null):runningTime>=AgGridReact.MAX_COMPONENT_CREATION_TIME?console.error("ag-Grid: React Component '"+reactComponent.getReactComponentName()+"' not created within "+AgGridReact.MAX_COMPONENT_CREATION_TIME+"ms"):window.setTimeout(function(){return _this.waitForInstance(reactComponent,resolve,runningTime+5)},5)};AgGridReact.prototype.mountReactPortal=
function(portal,reactComponent,resolve){this.portals=__spreadArrays(this.portals,[portal]);this.batchUpdate(this.waitForInstance(reactComponent,resolve))};AgGridReact.prototype.batchUpdate=function(callback){var _this=this;if(this.hasPendingPortalUpdate)return callback&&callback();setTimeout(function(){_this.api&&_this.forceUpdate(function(){callback&&callback();_this.hasPendingPortalUpdate=!1})});this.hasPendingPortalUpdate=!0};AgGridReact.prototype.destroyPortal=function(portal){this.portals=this.portals.filter(function(curPortal){return curPortal!==
portal});this.batchUpdate()};AgGridReact.prototype.getStrategyTypeForProp=function(propKey){if("rowData"===propKey){if(this.props.rowDataChangeDetectionStrategy)return this.props.rowDataChangeDetectionStrategy;if(this.props.deltaRowDataMode)return changeDetectionService_1.ChangeDetectionStrategyType.IdentityCheck}return changeDetectionService_1.ChangeDetectionStrategyType.DeepValueCheck};AgGridReact.prototype.shouldComponentUpdate=function(nextProps){this.processPropsChanges(this.props,nextProps);
return!1};AgGridReact.prototype.componentDidUpdate=function(prevProps){this.processPropsChanges(prevProps,this.props)};AgGridReact.prototype.processPropsChanges=function(prevProps,nextProps){var changes={};this.extractGridPropertyChanges(prevProps,nextProps,changes);this.extractDeclarativeColDefChanges(nextProps,changes);0<Object.keys(changes).length&&ag_grid_community_1.ComponentUtil.processOnChange(changes,this.gridOptions,this.api,this.columnApi)};AgGridReact.prototype.extractDeclarativeColDefChanges=
function(nextProps,changes){var debugLogging=!!nextProps.debug;if(agGridColumn_1.AgGridColumn.hasChildColumns(nextProps)){var detectionStrategy=this.changeDetectionService.getStrategy(changeDetectionService_1.ChangeDetectionStrategyType.DeepValueCheck),currentColDefs=this.gridOptions.columnDefs,newColDefs=agGridColumn_1.AgGridColumn.mapChildColumnDefs(nextProps);detectionStrategy.areEqual(currentColDefs,newColDefs)||(debugLogging&&console.log("agGridReact: colDefs definitions changed"),changes.columnDefs=
{previousValue:this.gridOptions.columnDefs,currentValue:agGridColumn_1.AgGridColumn.mapChildColumnDefs(nextProps)})}};AgGridReact.prototype.extractGridPropertyChanges=function(prevProps,nextProps,changes){var _this=this,debugLogging=!!nextProps.debug;Object.keys(nextProps).forEach(function(propKey){-1===ag_grid_community_1.ComponentUtil.ALL_PROPERTIES.indexOf(propKey)||_this.changeDetectionService.getStrategy(_this.getStrategyTypeForProp(propKey)).areEqual(prevProps[propKey],nextProps[propKey])||
(debugLogging&&console.log("agGridReact: ["+propKey+"] property changed"),changes[propKey]={previousValue:prevProps[propKey],currentValue:nextProps[propKey]})});ag_grid_community_1.ComponentUtil.getEventCallbacks().forEach(function(funcName){_this.props[funcName]!==nextProps[funcName]&&(debugLogging&&console.log("agGridReact: ["+funcName+"] event callback changed"),changes[funcName]={previousValue:prevProps[funcName],currentValue:nextProps[funcName]})})};AgGridReact.prototype.componentWillUnmount=
function(){this.api&&(this.api.destroy(),this.api=null);this.destroyed=!0};AgGridReact.MAX_COMPONENT_CREATION_TIME=1E3;return AgGridReact}(global.Component);exports.AgGridReact=AgGridReact;AgGridReact.propTypes={gridOptions:module.object};addProperties(ag_grid_community_1.ComponentUtil.getEventCallbacks(),module.func);addProperties(ag_grid_community_1.ComponentUtil.BOOLEAN_PROPERTIES,module.bool);addProperties(ag_grid_community_1.ComponentUtil.STRING_PROPERTIES,module.string);addProperties(ag_grid_community_1.ComponentUtil.OBJECT_PROPERTIES,
module.object);addProperties(ag_grid_community_1.ComponentUtil.ARRAY_PROPERTIES,module.array);addProperties(ag_grid_community_1.ComponentUtil.NUMBER_PROPERTIES,module.number);addProperties(ag_grid_community_1.ComponentUtil.FUNCTION_PROPERTIES,module.func);var ReactFrameworkComponentWrapper=function(_super){function ReactFrameworkComponentWrapper(agGridReact){var _this=_super.call(this)||this;_this.agGridReact=agGridReact;return _this}__extends(ReactFrameworkComponentWrapper,_super);ReactFrameworkComponentWrapper.prototype.createWrapper=
function(UserReactComponent){return new reactComponent_1.ReactComponent(UserReactComponent,this.agGridReact)};return ReactFrameworkComponentWrapper}(ag_grid_community_1.BaseComponentWrapper)}
//# sourceMappingURL=module$node_modules$ag_grid_react$lib$agGridReact.js.map

==> gorilla-notes-0.5.2.jar: public/js/compiled/cljs-runtime/module$node_modules$ag_grid_react$lib$agGridReact.js <==
shadow$provide.module$node_modules$ag_grid_react$lib$agGridReact=function(global,require,module,exports){function addProperties(listOfProps,propType){listOfProps.forEach(function(propKey){AgGridReact[propKey]=propType})}var __extends=this&&this.__extends||function(){var extendStatics=function(d$jscomp$0,b$jscomp$0){extendStatics=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(d,b){d.__proto__=b}||function(d,b){for(var p in b)b.hasOwnProperty(p)&&(d[p]=b[p])};return extendStatics(d$jscomp$0,
b$jscomp$0)};return function(d,b){function __(){this.constructor=d}extendStatics(d,b);d.prototype=null===b?Object.create(b):(__.prototype=b.prototype,new __)}}(),__spreadArrays=this&&this.__spreadArrays||function(){for(var s=0,i=0,il=arguments.length;i<il;i++)s+=arguments[i].length;s=Array(s);var k=0;for(i=0;i<il;i++)for(var a=arguments[i],j=0,jl=a.length;j<jl;j++,k++)s[k]=a[j];return s};Object.defineProperty(exports,"__esModule",{value:!0});var React=require("module$node_modules$react$index");global=
require("module$node_modules$react$index");module=require("module$node_modules$prop_types$index");var ag_grid_community_1=require("module$node_modules$ag_grid_community$dist$ag_grid_community_cjs"),agGridColumn_1=require("module$node_modules$ag_grid_react$lib$agGridColumn"),reactComponent_1=require("module$node_modules$ag_grid_react$lib$reactComponent"),changeDetectionService_1=require("module$node_modules$ag_grid_react$lib$changeDetectionService"),AgGridReact=function(_super){function AgGridReact(props,
state){var _this=_super.call(this,props,state)||this;_this.props=props;_this.state=state;_this.changeDetectionService=new changeDetectionService_1.ChangeDetectionService;_this.api=null;_this.portals=[];_this.hasPendingPortalUpdate=!1;_this.destroyed=!1;return _this}__extends(AgGridReact,_super);AgGridReact.prototype.render=function(){var _this=this;return React.createElement("div",{style:this.createStyleForDiv(),ref:function(e){_this.eGridDiv=e}},this.portals)};AgGridReact.prototype.createStyleForDiv=
function(){var style={height:"100%"},containerStyle=this.props.containerStyle;containerStyle&&Object.keys(containerStyle).forEach(function(key){style[key]=containerStyle[key]});return style};AgGridReact.prototype.componentDidMount=function(){var modules=this.props.modules||[];modules={providedBeanInstances:{agGridReact:this,frameworkComponentWrapper:new ReactFrameworkComponentWrapper(this)},modules:modules};var gridOptions=this.props.gridOptions||{};agGridColumn_1.AgGridColumn.hasChildColumns(this.props)&&
(gridOptions.columnDefs=agGridColumn_1.AgGridColumn.mapChildColumnDefs(this.props));this.gridOptions=ag_grid_community_1.ComponentUtil.copyAttributesToGridOptions(gridOptions,this.props);new ag_grid_community_1.Grid(this.eGridDiv,this.gridOptions,modules);this.api=this.gridOptions.api;this.columnApi=this.gridOptions.columnApi};AgGridReact.prototype.waitForInstance=function(reactComponent,resolve,runningTime){var _this=this;void 0===runningTime&&(runningTime=0);this.destroyed?resolve(null):reactComponent.isStatelessComponent()&&
reactComponent.statelessComponentRendered()?resolve(null):!reactComponent.isStatelessComponent()&&reactComponent.getFrameworkComponentInstance()?resolve(null):runningTime>=AgGridReact.MAX_COMPONENT_CREATION_TIME?console.error("ag-Grid: React Component '"+reactComponent.getReactComponentName()+"' not created within "+AgGridReact.MAX_COMPONENT_CREATION_TIME+"ms"):window.setTimeout(function(){return _this.waitForInstance(reactComponent,resolve,runningTime+5)},5)};AgGridReact.prototype.mountReactPortal=
function(portal,reactComponent,resolve){this.portals=__spreadArrays(this.portals,[portal]);this.batchUpdate(this.waitForInstance(reactComponent,resolve))};AgGridReact.prototype.batchUpdate=function(callback){var _this=this;if(this.hasPendingPortalUpdate)return callback&&callback();setTimeout(function(){_this.api&&_this.forceUpdate(function(){callback&&callback();_this.hasPendingPortalUpdate=!1})});this.hasPendingPortalUpdate=!0};AgGridReact.prototype.destroyPortal=function(portal){this.portals=this.portals.filter(function(curPortal){return curPortal!==
portal});this.batchUpdate()};AgGridReact.prototype.getStrategyTypeForProp=function(propKey){if("rowData"===propKey){if(this.props.rowDataChangeDetectionStrategy)return this.props.rowDataChangeDetectionStrategy;if(this.props.deltaRowDataMode)return changeDetectionService_1.ChangeDetectionStrategyType.IdentityCheck}return changeDetectionService_1.ChangeDetectionStrategyType.DeepValueCheck};AgGridReact.prototype.shouldComponentUpdate=function(nextProps){this.processPropsChanges(this.props,nextProps);
return!1};AgGridReact.prototype.componentDidUpdate=function(prevProps){this.processPropsChanges(prevProps,this.props)};AgGridReact.prototype.processPropsChanges=function(prevProps,nextProps){var changes={};this.extractGridPropertyChanges(prevProps,nextProps,changes);this.extractDeclarativeColDefChanges(nextProps,changes);0<Object.keys(changes).length&&ag_grid_community_1.ComponentUtil.processOnChange(changes,this.gridOptions,this.api,this.columnApi)};AgGridReact.prototype.extractDeclarativeColDefChanges=
function(nextProps,changes){var debugLogging=!!nextProps.debug;if(agGridColumn_1.AgGridColumn.hasChildColumns(nextProps)){var detectionStrategy=this.changeDetectionService.getStrategy(changeDetectionService_1.ChangeDetectionStrategyType.DeepValueCheck),currentColDefs=this.gridOptions.columnDefs,newColDefs=agGridColumn_1.AgGridColumn.mapChildColumnDefs(nextProps);detectionStrategy.areEqual(currentColDefs,newColDefs)||(debugLogging&&console.log("agGridReact: colDefs definitions changed"),changes.columnDefs=
{previousValue:this.gridOptions.columnDefs,currentValue:agGridColumn_1.AgGridColumn.mapChildColumnDefs(nextProps)})}};AgGridReact.prototype.extractGridPropertyChanges=function(prevProps,nextProps,changes){var _this=this,debugLogging=!!nextProps.debug;Object.keys(nextProps).forEach(function(propKey){-1===ag_grid_community_1.ComponentUtil.ALL_PROPERTIES.indexOf(propKey)||_this.changeDetectionService.getStrategy(_this.getStrategyTypeForProp(propKey)).areEqual(prevProps[propKey],nextProps[propKey])||
(debugLogging&&console.log("agGridReact: ["+propKey+"] property changed"),changes[propKey]={previousValue:prevProps[propKey],currentValue:nextProps[propKey]})});ag_grid_community_1.ComponentUtil.getEventCallbacks().forEach(function(funcName){_this.props[funcName]!==nextProps[funcName]&&(debugLogging&&console.log("agGridReact: ["+funcName+"] event callback changed"),changes[funcName]={previousValue:prevProps[funcName],currentValue:nextProps[funcName]})})};AgGridReact.prototype.componentWillUnmount=
function(){this.api&&(this.api.destroy(),this.api=null);this.destroyed=!0};AgGridReact.MAX_COMPONENT_CREATION_TIME=1E3;return AgGridReact}(global.Component);exports.AgGridReact=AgGridReact;AgGridReact.propTypes={gridOptions:module.object};addProperties(ag_grid_community_1.ComponentUtil.getEventCallbacks(),module.func);addProperties(ag_grid_community_1.ComponentUtil.BOOLEAN_PROPERTIES,module.bool);addProperties(ag_grid_community_1.ComponentUtil.STRING_PROPERTIES,module.string);addProperties(ag_grid_community_1.ComponentUtil.OBJECT_PROPERTIES,
module.object);addProperties(ag_grid_community_1.ComponentUtil.ARRAY_PROPERTIES,module.array);addProperties(ag_grid_community_1.ComponentUtil.NUMBER_PROPERTIES,module.number);addProperties(ag_grid_community_1.ComponentUtil.FUNCTION_PROPERTIES,module.func);var ReactFrameworkComponentWrapper=function(_super){function ReactFrameworkComponentWrapper(agGridReact){var _this=_super.call(this)||this;_this.agGridReact=agGridReact;return _this}__extends(ReactFrameworkComponentWrapper,_super);ReactFrameworkComponentWrapper.prototype.createWrapper=
function(UserReactComponent){return new reactComponent_1.ReactComponent(UserReactComponent,this.agGridReact)};return ReactFrameworkComponentWrapper}(ag_grid_community_1.BaseComponentWrapper)}
//# sourceMappingURL=module$node_modules$ag_grid_react$lib$agGridReact.js.map
